;
;   Module name      :	OpenIEWindow.au3
;   Version          :	1.01
;   Started on       :	December 12, 2010
;   Completed on     :	December 28, 2010
;   Author           :  J.Hubb
;
;   Module type      :	Main
;   Description      :	Opens a IE window, setting various attributes
;
;   Developed under  :	AutoIt 3.2.10.0
;   Sw requirements  :	CmdLine.au3
;
;   Parameters       :	None
;   Notes - usage    :	See Help message (run the program with "/?" parameter)
;


;--- Global directives -----------------------------------------------------------------------------



#NoTrayIcon
; Opt("TrayIconDebug", 1)		; Remove comment to enable during debug

Opt("MustDeclareVars", 1)
Opt("GUICloseOnESC", 0)



;--- Include files ---------------------------------------------------------------------------------



#include <Constants.au3>
#include <CmdLine.au3>



;--- Global constants ------------------------------------------------------------------------------



const $FILE_NAME = "OpenIEWindow.au3"
const $MODULE_VER = "1.01"
const $MODULE_NAME = $FILE_NAME & " " & $MODULE_VER & "; Open Source on December 28, 2010 by J.Hubb."

; Error codes
const $NO_ERROR = 0
const $PARAM_ERR = 255

const $URL_DEF = "about:blank"

; Help messages, switches and parameters
const $HELP_MSG = _
	"Usage: " & $FILE_NAME & " [/?] [/ver] [Url <u>] [Geom] [Features]" & @CR & _
	@CR & _
	"Opens an IE window, setting following available attributes:" & @CR & _
	"Geom:" & @TAB & " [X <x>] [Y <y>] [Width <w>] [Height <h>]" & @CR & _
	"Features:" & @TAB & " [MenuBar <st>] [ToolBar <st>] [AddrBar <st>]" & @CR & _
			@TAB & " [StatusBar <st>] [Resizable <st>]" & @CR & _
	"For each <st>, default status is off." & @CR

; Switch definitions (the first must be: $SWITCH_ERR = $CL_SWITCH_ERR)
enum $SWITCH_ERR = $CL_SWITCH_ERR, $SWITCH_HELP, $SWITCH_VER, $SWITCH_URL, $SWITCH_X, $SWITCH_Y, $SWITCH_WIDTH, $SWITCH_HEIGHT, _
		$SWITCH_MENUBAR, $SWITCH_TOOLBAR, $SWITCH_ADDRBAR, $SWITCH_STATUSBAR, $SWITCH_RESIZE
const $SWITCH_COUNT = 13									; Total number of switch definitions
const $SWITCH[$SWITCH_COUNT][4] = _
	[ _
		[$SWITCH_ERR,		"",			0,	""], _
		[$SWITCH_HELP,		"/?",		0,	" display this help and exit"], _
		[$SWITCH_VER,		"/ver",		0,	" print version information and exit"], _
		[$SWITCH_URL,		"Url",		1,	" url <u> of the page (default: '" & $URL_DEF & "')"], _
		[$SWITCH_X,			"X",		1,	" position <x> (integer) of IE window"], _
		[$SWITCH_Y,			"Y",		1,	" position <y> (integer) of IE window"], _
		[$SWITCH_WIDTH,		"Width",	1,	" width <w> (integer) of IE window"], _
		[$SWITCH_HEIGHT,	"Height",	1,	" height <h> (integer) of IE window"], _
		[$SWITCH_MENUBAR,	"MenuBar",	1,	" Menu Bar <on|off>"], _
		[$SWITCH_TOOLBAR,	"ToolBar",	1,	" Tool Bar <on|off>"], _
		[$SWITCH_ADDRBAR,	"AddrBar",	1,	" Address Bar <on|off>"], _
		[$SWITCH_STATUSBAR,	"StatusBar",1,	" Status Bar <on|off>"], _
		[$SWITCH_RESIZE,	"Resizable",1,	" Resizable window <on|off>"] _
	]



;--- Global variables ------------------------------------------------------------------------------



global $Curr_switch, $Curr_switch_ndx, $Curr_params_ndx
global $Url = $URL_DEF
global $IE_obj



;--- Functions code --------------------------------------------------------------------------------



func ShowError($msg, $code = $NO_ERROR)
;---
; Displays in a Message Box an error message and stops the execution of the script with the
; specified exit code or $NO_ERROR if not specified.
;
; $msg	error message
; $code	exit code
; ret	nothing
;---
	MsgBox($MB_OK + $MB_ICONHAND, $FILE_NAME, $msg)
	Exit($code)
endfunc



func ShowHelp()
;---
; Displays in a Message Box the help message and stops the execution of the script.
;
; ret	nothing
;---
	local $s = $HELP_MSG
	local $n
	
	for $n = 1 to ($SWITCH_COUNT - 1)
		$s &= @CR & $SWITCH[$n][1] & Chr(9) & $SWITCH[$n][3]
	next
	MsgBox($MB_OK + $MB_ICONASTERISK, $FILE_NAME, $s)
	Exit
endfunc



func ShowVersion()
;---
; Displays in a Message Box the version message and stops the execution of the script.
;
; ret	nothing
;---
	MsgBox($MB_OK + $MB_ICONASTERISK, $FILE_NAME, $MODULE_NAME)
	Exit
endfunc



func ShowWarning($msg)
;---
; Displays in a Message Box a warning message without stopping the execution of the script.
;
; $msg	warning message
; ret	nothing
;---
	MsgBox($MB_OK + $MB_ICONEXCLAMATION, $FILE_NAME, $msg)
endfunc



func Str2Bool($s)
;---
; Converts the string $s into a boolean value. On errors, returns False
;
; $s	string to be converted
; ret	corresponding boolean value
;---
	switch StringLower($s)
		case "on", "1", "true"
			return True
		case else
			return False
	endswitch
endfunc



;--- Main code -------------------------------------------------------------------------------------



if ($CmdLine[0] == 0) then
	ShowHelp()
endif

$IE_obj = ObjCreate("InternetExplorer.Application");
$IE_obj.MenuBar = False;
$IE_obj.ToolBar = False;
$IE_obj.AddressBar = False;
$IE_obj.StatusBar = False;
$IE_obj.Resizable = False;

while (CLGetOpts($SWITCH, $Curr_switch, $Curr_switch_ndx, $Curr_params_ndx))
	switch $Curr_switch
		case $SWITCH_ERR
			ShowError("parameter '" & $CmdLine[$Curr_switch_ndx] & "' incorrect or incomplete", $PARAM_ERR)
		case $SWITCH_HELP
			ShowHelp()
		case $SWITCH_VER
			ShowVersion()
		case $SWITCH_URL
			$Url = $CmdLine[$Curr_params_ndx]
		case $SWITCH_X
			$IE_obj.Left = Number($CmdLine[$Curr_params_ndx])
		case $SWITCH_Y
			$IE_obj.Top = Number($CmdLine[$Curr_params_ndx])
		case $SWITCH_WIDTH
			$IE_obj.Width = Number($CmdLine[$Curr_params_ndx])
		case $SWITCH_HEIGHT
			$IE_obj.Height = Number($CmdLine[$Curr_params_ndx])
		case $SWITCH_MENUBAR
			$IE_obj.MenuBar = Str2Bool($CmdLine[$Curr_params_ndx])
		case $SWITCH_TOOLBAR
			$IE_obj.ToolBar = Str2Bool($CmdLine[$Curr_params_ndx])
		case $SWITCH_ADDRBAR
			$IE_obj.AddressBar = Str2Bool($CmdLine[$Curr_params_ndx])
		case $SWITCH_STATUSBAR
			$IE_obj.StatusBar = Str2Bool($CmdLine[$Curr_params_ndx])
		case $SWITCH_RESIZE
			$IE_obj.Resizable = Str2Bool($CmdLine[$Curr_params_ndx])
	endswitch
wend

$IE_obj.Navigate($Url);
$IE_obj.Visible = True;
